@@ -166,7 +166,7 @@ function Graph() {
                   return d.type;
               })
               .attr("fill", function(d) {
-                  var index = self.parameter_types.indexOf(d.type);
+                  var index = window.parameter_types.indexOf(d.type);
                   return roy.tools.color(index);
               });
 
@@ -196,7 +196,7 @@ function Graph() {
                   .attr("transform", "translate(0)")
                   .attr("d", self.line_func)
                   .attr("stroke", function(d) {
-                      var index = self.parameter_types.indexOf(parameter_type);
+                      var index = window.parameter_types.indexOf(parameter_type);
                       return roy.tools.color(index);
                   })
                   //.attr("class", parameter_type+"_line")
