@@ -84,8 +84,11 @@ function register_new_parameter (parameter) {
         .text("0");
     window.parameters[parameter.type] = [];
     var graph = new Graph();
-    graph.parameter_types.push(parameter.type);
+    graph.register_parameter_type(parameter.type);
     graph.set_title(parameter.type);
+    window.graphs.forEach(function(graph){
+        graph.refresh_parameter_list();
+    });
 }
 
 
@@ -123,10 +126,15 @@ function calculate_parameter_rate (parameter) {
 
 
 function update_graphs (parameter) {
-    for (var index in window.graphs) {
-        var graph = window.graphs[index];
+    //for (var index in window.graphs) {
+    //    var graph = window.graphs[index];
+    //    if (roy.tools.includes(graph.parameter_types, parameter.type)) {
+    //        graph.redraw();
+    //    }
+    //}
+    window.graphs.forEach(function(graph) {
         if (roy.tools.includes(graph.parameter_types, parameter.type)) {
             graph.redraw();
         }
-    }
+    });
 }
